# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v1.0.0] - 28.04.2021

- Initial release

[v1.0.0]: https://github.com/denisvasilik/binalyzer-wasm/tree/v1.0.0
